Learn R Programming

calmr (version 0.7.0)

calmr-package: calmr: Canonical Associative Learning Models and their Representations

Description

logo

Implementations of canonical associative learning models, with tools to run experiment simulations, estimate model parameters, and compare model representations. Experiments and results are represented using S4 classes and methods.

Arguments

Author

Maintainer: Victor Navarro navarrov@cardiff.ac.uk [copyright holder]

See Also